public abstract class Function {

    /**
     * Returns a string representation of this function.
     */
    public abstract String toString();

    /**
     * Returns the value of this function at x.
     * 
     * @param x The value to evaluate the function at.
     * @return The value of y at x.
     */
    public abstract double valueAt(double x);
    
    /**
     * Returns the area under the curve from <code>x1</code> to <code>x2</code>.
     * 
     * @param x1 The lower bound.
     * @param x2 The upper bound.
     * @return The area under the curve in the specified interval.
     */
    public abstract double area(double x1, double x2);
    
    /**
     * Gets the derivative of this function.
     */
    public abstract Function getDerivFunc();
    
    /**
     * Gets the antiderivative of this function.
     */
    public abstract Function getAntiderivFunc();
}
